"""Tests for the Step Functions Tool MCP Server."""


# https://github.com/awslabs/mcp/issues/167
# https://github.com/awslabs/mcp/issues/425
# def test_version_matches_pyproject():
#     """Test that the version in server.py matches pyproject.toml."""
#     import pathlib
#     import tomli

#     # Read pyproject.toml
#     pyproject_path = pathlib.Path(__file__).parent.parent / 'pyproject.toml'
#     with open(pyproject_path, 'rb') as f:
#         pyproject = tomli.load(f)

#     # Get version from pyproject.toml
#     pyproject_version = pyproject['project']['version']

#     # Verify versions match
#     assert __version__ == pyproject_version, (
#         f'Version mismatch: server.py has version {__version__}, '
#         f'but pyproject.toml has version {pyproject_version}'
#     )



"""Tests for the register_state_machines function."""

import logging
import pytest
from unittest.mock import MagicMock, patch


with pytest.MonkeyPatch().context() as CTX:
    CTX.setattr('boto3.Session', MagicMock)
    from awslabs.stepfunctions_tool_mcp_server.server import mcp, register_state_machines


class TestRegisterStateMachines:
    """Tests for the register_state_machines function."""

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_PREFIX', 'prefix-')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.create_state_machine_tool')
    def test_register_machines_with_prefix(self, mock_create_tool, mock_sfn_client):
        """Test registering state machines filtered by prefix."""
        # Set up test data
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'name': 'test-state-machine',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine',
                    'type': 'STANDARD',
                },
                {
                    'name': 'prefix-test-machine',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:prefix-test-machine',
                    'type': 'STANDARD',
                },
            ]
        }

        # Call the function
        register_state_machines()

        # Verify results
        assert mock_create_tool.call_count == 1
        mock_create_tool.assert_called_with(
            'prefix-test-machine',
            'arn:aws:states:us-east-1:123456789012:stateMachine:prefix-test-machine',
            'STANDARD',
            'AWS Step Functions state machine: prefix-test-machine',
            None,
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_LIST', ['machine1', 'machine2']
    )
    @patch('awslabs.stepfunctions_tool_mcp_server.server.create_state_machine_tool')
    def test_register_machines_with_list(self, mock_create_tool, mock_sfn_client):
        """Test registering state machines filtered by list."""
        # Set up test data
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'name': 'machine1',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:machine1',
                    'type': 'STANDARD',
                },
                {
                    'name': 'machine2',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:machine2',
                    'type': 'STANDARD',
                },
                {
                    'name': 'machine3',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:machine3',
                    'type': 'STANDARD',
                },
            ]
        }

        # Call the function
        register_state_machines()

        # Verify results
        assert mock_create_tool.call_count == 2
        mock_create_tool.assert_any_call(
            'machine1',
            'arn:aws:states:us-east-1:123456789012:stateMachine:machine1',
            'STANDARD',
            'AWS Step Functions state machine: machine1',
            None,
        )
        mock_create_tool.assert_any_call(
            'machine2',
            'arn:aws:states:us-east-1:123456789012:stateMachine:machine2',
            'STANDARD',
            'AWS Step Functions state machine: machine2',
            None,
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_TAG_KEY', 'test-key')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_TAG_VALUE', 'test-value')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.create_state_machine_tool')
    def test_register_machines_with_tags(self, mock_create_tool, mock_sfn_client):
        """Test registering state machines filtered by tags."""
        # Set up test data
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'name': 'tagged-machine',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:tagged-machine',
                    'type': 'STANDARD',
                },
            ]
        }
        mock_sfn_client.list_tags_for_resource.return_value = {
            'tags': [{'key': 'test-key', 'value': 'test-value'}]
        }

        # Call the function
        register_state_machines()

        # Verify results
        mock_create_tool.assert_called_once_with(
            'tagged-machine',
            'arn:aws:states:us-east-1:123456789012:stateMachine:tagged-machine',
            'STANDARD',
            'AWS Step Functions state machine: tagged-machine',
            None,
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.create_state_machine_tool')
    def test_register_machines_with_comments(self, mock_create_tool, mock_sfn_client):
        """Test registering state machines with workflow comments."""
        # Set up test data
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'name': 'test-machine',
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:test-machine',
                    'type': 'STANDARD',
                },
            ]
        }
        mock_sfn_client.describe_state_machine.return_value = {
            'description': 'Test Description',
            'definition': '{"Comment": "Workflow Comment", "StartAt": "State1", "States": {"State1": {"Type": "Pass", "End": true}}}',
        }

        # Call the function
        register_state_machines()

        # Verify results
        mock_create_tool.assert_called_once_with(
            'test-machine',
            'arn:aws:states:us-east-1:123456789012:stateMachine:test-machine',
            'STANDARD',
            'Test Description\n\nWorkflow Description: Workflow Comment',
            None,
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_TAG_KEY', 'test-key')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_TAG_VALUE', '')
    def test_register_machines_incomplete_tag_config(self, mock_sfn_client, caplog):
        """Test registering state machines with incomplete tag configuration."""
        # Set up test data
        mock_sfn_client.list_state_machines.return_value = {'stateMachines': []}

        # Call the function and check logging
        with caplog.at_level(logging.WARNING):
            register_state_machines()

            # Verify warning was logged
            assert (
                'Both STATE_MACHINE_TAG_KEY and STATE_MACHINE_TAG_VALUE must be set to filter by tag'
                in caplog.text
            )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    def test_register_machines_error_handling(self, mock_sfn_client, caplog):
        """Test error handling during state machine registration."""
        # Set up mock to raise an exception
        mock_sfn_client.list_state_machines.side_effect = Exception('List error')

        # Call the function and check logging
        with caplog.at_level(logging.ERROR):
            register_state_machines()

            # Verify error was logged
            assert 'Error registering Step Functions state machines as tools' in caplog.text
            assert 'List error' in caplog.text

    def test_mcp_server_initialization(self):
        """Test MCP server initialization."""
        # Verify server configuration
        assert mcp.name == 'awslabs.stepfunctions-tool-mcp-server'
        assert (
            mcp.instructions is not None
            and 'Use AWS Step Functions state machines' in mcp.instructions
        )
        assert 'pydantic' in mcp.dependencies
        assert 'boto3' in mcp.dependencies



"""Tests for Express state machine functionality."""

import json
import pytest
from mcp.server.fastmcp import Context
from unittest.mock import AsyncMock, MagicMock, patch


with pytest.MonkeyPatch().context() as CTX:
    CTX.setattr('boto3.Session', MagicMock)
    from awslabs.stepfunctions_tool_mcp_server.server import invoke_express_state_machine_impl


class TestExpressStateMachines:
    """Tests for Express state machine functionality."""

    @pytest.mark.asyncio
    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    async def test_express_state_machine_success(self, mock_sfn_client):
        """Test successful execution of an Express state machine."""
        # Set up the mock
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
                    'name': 'express-test',
                    'type': 'EXPRESS',
                    'creationDate': '2023-01-01T00:00:00Z',
                },
            ]
        }

        mock_sfn_client.start_sync_execution.return_value = {
            'executionArn': 'arn:aws:states:us-east-1:123456789012:express:express-test:12345',
            'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            'name': '12345',
            'startDate': '2023-01-01T00:00:00Z',
            'stopDate': '2023-01-01T00:00:01Z',
            'status': 'SUCCEEDED',
            'output': '{"result": "success"}',
        }

        # Create a mock context
        ctx = MagicMock(spec=Context)
        ctx.info = AsyncMock()
        ctx.error = AsyncMock()

        # Call the function
        result = await invoke_express_state_machine_impl(
            'express-test',
            'arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            {'param': 'value'},
            ctx,
        )

        # Check that the state machine was invoked with the correct parameters
        mock_sfn_client.start_sync_execution.assert_called_once_with(
            stateMachineArn='arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            input='{"param": "value"}',
        )

        # Check that the context methods were called
        ctx.info.assert_called()

        # Check the result
        assert 'State machine express-test returned:' in result
        assert '"result": "success"' in result

    @pytest.mark.asyncio
    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    async def test_express_state_machine_failure(self, mock_sfn_client):
        """Test failed execution of an Express state machine."""
        # Set up the mock
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-error',
                    'name': 'express-error',
                    'type': 'EXPRESS',
                    'creationDate': '2023-01-01T00:00:00Z',
                },
            ]
        }

        mock_sfn_client.start_sync_execution.return_value = {
            'executionArn': 'arn:aws:states:us-east-1:123456789012:express:express-error:12345',
            'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-error',
            'name': '12345',
            'startDate': '2023-01-01T00:00:00Z',
            'stopDate': '2023-01-01T00:00:01Z',
            'status': 'FAILED',
            'error': 'States.TaskFailed',
            'cause': 'Something went wrong',
        }

        # Create a mock context
        ctx = MagicMock(spec=Context)
        ctx.info = AsyncMock()
        ctx.error = AsyncMock()

        # Call the function
        result = await invoke_express_state_machine_impl(
            'express-error',
            'arn:aws:states:us-east-1:123456789012:stateMachine:express-error',
            {'param': 'value'},
            ctx,
        )

        # Check that the state machine was invoked with the correct parameters
        mock_sfn_client.start_sync_execution.assert_called_once_with(
            stateMachineArn='arn:aws:states:us-east-1:123456789012:stateMachine:express-error',
            input='{"param": "value"}',
        )

        # Check that the context methods were called
        ctx.info.assert_called()
        ctx.error.assert_called_once()

        # Check the result
        assert 'Express state machine express-error execution failed with status: FAILED' in result
        assert 'error: States.TaskFailed' in result
        assert 'cause: Something went wrong' in result

    @pytest.mark.asyncio
    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    async def test_express_state_machine_direct_invocation(self, mock_sfn_client):
        """Test direct invocation of an Express state machine."""
        # Set up the mock
        mock_sfn_client.start_sync_execution.return_value = {
            'executionArn': 'arn:aws:states:us-east-1:123456789012:express:express-test:12345',
            'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            'name': '12345',
            'startDate': '2023-01-01T00:00:00Z',
            'stopDate': '2023-01-01T00:00:01Z',
            'status': 'SUCCEEDED',
            'output': '{"result": "direct success"}',
        }

        # Create a mock context
        ctx = MagicMock(spec=Context)
        ctx.info = AsyncMock()
        ctx.error = AsyncMock()

        # Call the function directly
        result = await invoke_express_state_machine_impl(
            'express-test',
            'arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            {'param': 'value'},
            ctx,
        )

        # Check that the state machine was invoked with the correct parameters
        mock_sfn_client.start_sync_execution.assert_called_once_with(
            stateMachineArn='arn:aws:states:us-east-1:123456789012:stateMachine:express-test',
            input='{"param": "value"}',
        )

        # Check that the context methods were called
        ctx.info.assert_called()

        # Check the result
        assert 'State machine express-test returned:' in result
        assert '"result": "direct success"' in result

    @pytest.mark.asyncio
    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    async def test_express_state_machine_complex_input(self, mock_sfn_client):
        """Test Express state machine with complex input and output."""
        # Set up complex input
        complex_input = {
            'data': {
                'nested': {
                    'array': [1, 2, 3],
                    'object': {'key': 'value'},
                    'null': None,
                    'boolean': True,
                }
            },
            'metadata': {'timestamp': '2023-01-01T00:00:00Z', 'requestId': '12345'},
        }

        # Set up the mock
        mock_sfn_client.list_state_machines.return_value = {
            'stateMachines': [
                {
                    'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-complex',
                    'name': 'express-complex',
                    'type': 'EXPRESS',
                    'creationDate': '2023-01-01T00:00:00Z',
                },
            ]
        }

        mock_sfn_client.start_sync_execution.return_value = {
            'executionArn': 'arn:aws:states:us-east-1:123456789012:express:express-complex:12345',
            'stateMachineArn': 'arn:aws:states:us-east-1:123456789012:stateMachine:express-complex',
            'name': '12345',
            'startDate': '2023-01-01T00:00:00Z',
            'stopDate': '2023-01-01T00:00:01Z',
            'status': 'SUCCEEDED',
            'output': json.dumps(complex_input),
        }

        # Create a mock context
        ctx = MagicMock(spec=Context)
        ctx.info = AsyncMock()
        ctx.error = AsyncMock()

        # Call the function
        result = await invoke_express_state_machine_impl(
            'express-complex',
            'arn:aws:states:us-east-1:123456789012:stateMachine:express-complex',
            complex_input,
            ctx,
        )

        # Check that the state machine was invoked with the correct parameters
        mock_sfn_client.start_sync_execution.assert_called_once_with(
            stateMachineArn='arn:aws:states:us-east-1:123456789012:stateMachine:express-complex',
            input=json.dumps(complex_input),
        )

        # Check the result
        assert 'State machine express-complex returned:' in result
        assert '"data": {' in result
        assert '"nested": {' in result
        assert '"array": [' in result
        assert '"metadata": {' in result



"""Tests for the get_schema_arn_from_state_machine_arn function."""

import logging
import pytest
from unittest.mock import MagicMock, patch


with pytest.MonkeyPatch().context() as CTX:
    CTX.setattr('boto3.Session', MagicMock)
    from awslabs.stepfunctions_tool_mcp_server.server import get_schema_arn_from_state_machine_arn


class TestGetSchemaArn:
    """Tests for schema ARN retrieval from state machine tags."""

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_INPUT_SCHEMA_ARN_TAG_KEY',
        'schema-arn-tag',
    )
    def test_get_schema_arn_success(self, mock_sfn_client):
        """Test successful retrieval of schema ARN from state machine tags."""
        # Set up test data
        state_machine_arn = 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine'
        schema_arn = 'arn:aws:schemas:us-east-1:123456789012:schema/registry/schema'

        # Set up mock response
        mock_sfn_client.list_tags_for_resource.return_value = {
            'tags': [{'key': 'schema-arn-tag', 'value': schema_arn}]
        }

        # Call the function
        result = get_schema_arn_from_state_machine_arn(state_machine_arn)

        # Verify results
        assert result == schema_arn
        mock_sfn_client.list_tags_for_resource.assert_called_once_with(
            resourceArn=state_machine_arn
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_INPUT_SCHEMA_ARN_TAG_KEY', None
    )
    def test_get_schema_arn_no_tag_key(self, mock_sfn_client):
        """Test when schema ARN tag key is not configured."""
        # Set up test data
        state_machine_arn = 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine'

        # Call the function
        result = get_schema_arn_from_state_machine_arn(state_machine_arn)

        # Verify results
        assert result is None
        mock_sfn_client.list_tags_for_resource.assert_not_called()

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_INPUT_SCHEMA_ARN_TAG_KEY',
        'schema-arn-tag',
    )
    def test_get_schema_arn_tag_not_found(self, mock_sfn_client):
        """Test when schema ARN tag is not found on the state machine."""
        # Set up test data
        state_machine_arn = 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine'

        # Set up mock response with different tag
        mock_sfn_client.list_tags_for_resource.return_value = {
            'tags': [{'key': 'different-tag', 'value': 'some-value'}]
        }

        # Call the function
        result = get_schema_arn_from_state_machine_arn(state_machine_arn)

        # Verify results
        assert result is None
        mock_sfn_client.list_tags_for_resource.assert_called_once_with(
            resourceArn=state_machine_arn
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_INPUT_SCHEMA_ARN_TAG_KEY',
        'schema-arn-tag',
    )
    def test_get_schema_arn_error_handling(self, mock_sfn_client, caplog):
        """Test error handling during tag retrieval."""
        # Set up test data
        state_machine_arn = 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine'

        # Set up mock to raise an exception
        mock_sfn_client.list_tags_for_resource.side_effect = Exception('Tag retrieval error')

        # Call the function and check logging
        with caplog.at_level(logging.WARNING):
            result = get_schema_arn_from_state_machine_arn(state_machine_arn)

            # Verify results
            assert result is None
            assert 'Error checking tags for state machine' in caplog.text
            assert 'Tag retrieval error' in caplog.text

        # Verify mock calls
        mock_sfn_client.list_tags_for_resource.assert_called_once_with(
            resourceArn=state_machine_arn
        )

    @patch('awslabs.stepfunctions_tool_mcp_server.server.sfn_client')
    @patch(
        'awslabs.stepfunctions_tool_mcp_server.server.STATE_MACHINE_INPUT_SCHEMA_ARN_TAG_KEY',
        'schema-arn-tag',
    )
    def test_get_schema_arn_empty_tags(self, mock_sfn_client):
        """Test when state machine has no tags."""
        # Set up test data
        state_machine_arn = 'arn:aws:states:us-east-1:123456789012:stateMachine:test-state-machine'

        # Set up mock response with empty tags
        mock_sfn_client.list_tags_for_resource.return_value = {'tags': []}

        # Call the function
        result = get_schema_arn_from_state_machine_arn(state_machine_arn)

        # Verify results
        assert result is None
        mock_sfn_client.list_tags_for_resource.assert_called_once_with(
            resourceArn=state_machine_arn
        )



"""Tests for the main function."""

import pytest
from unittest.mock import MagicMock, patch


with pytest.MonkeyPatch().context() as CTX:
    CTX.setattr('boto3.Session', MagicMock)
    from awslabs.stepfunctions_tool_mcp_server.server import main


class TestMain:
    """Tests for the main function."""

    @patch('awslabs.stepfunctions_tool_mcp_server.server.register_state_machines')
    @patch('awslabs.stepfunctions_tool_mcp_server.server.mcp')
    @patch('argparse.ArgumentParser.parse_args')
    def test_main_stdio_transport(self, mock_parse_args, mock_mcp, mock_register):
        """Test main function with stdio transport."""
        # Set up test data
        mock_parse_args.return_value = MagicMock()

        # Call the function
        main()

        # Verify results
        mock_register.assert_called_once()
        mock_mcp.run.assert_called_once_with()



"""Tests for the AWS Helper."""

import os
from awslabs.stepfunctions_tool_mcp_server.aws_helper import AwsHelper
from awslabs.stepfunctions_tool_mcp_server.server import __version__
from unittest.mock import ANY, MagicMock, patch


class TestAwsHelper:
    """Tests for the AwsHelper class."""

    def test_get_aws_region_default(self):
        """Test that get_aws_region returns the default region."""
        with patch.dict(os.environ, {}, clear=True):
            region = AwsHelper.get_aws_region()
            assert region == 'us-east-1'

    @patch.dict(os.environ, {'AWS_REGION': 'us-west-2'})
    def test_get_aws_region_from_env(self):
        """Test that get_aws_region returns the region from the environment."""
        region = AwsHelper.get_aws_region()
        assert region == 'us-west-2'

    @patch.dict(os.environ, {'AWS_PROFILE': 'test-profile'})
    def test_get_aws_profile_from_env(self):
        """Test that get_aws_profile returns the profile from the environment."""
        profile = AwsHelper.get_aws_profile()
        assert profile == 'test-profile'

    @patch('boto3.Session')
    def test_create_boto3_client_with_profile(self, mock_boto3_session):
        """Test client creation with profile."""
        mock_session = MagicMock()
        mock_boto3_session.return_value = mock_session

        with patch.object(AwsHelper, 'get_aws_profile', return_value='test-profile'):
            with patch.object(AwsHelper, 'get_aws_region', return_value='us-west-2'):
                AwsHelper.create_boto3_client('stepfunctions')
                mock_boto3_session.assert_called_once_with(profile_name='test-profile')
                mock_session.client.assert_called_once_with(
                    'stepfunctions', region_name='us-west-2', config=ANY
                )

    @patch('boto3.client')
    def test_create_boto3_client_without_profile(self, mock_boto3_client):
        """Test client creation without profile."""
        with patch.object(AwsHelper, 'get_aws_profile', return_value=None):
            with patch.object(AwsHelper, 'get_aws_region', return_value='us-west-2'):
                AwsHelper.create_boto3_client('stepfunctions')
                mock_boto3_client.assert_called_once_with(
                    'stepfunctions', region_name='us-west-2', config=ANY
                )

    def test_create_boto3_client_user_agent(self):
        """Test that create_boto3_client sets the user agent correctly."""
        mock_session = MagicMock()
        with patch('boto3.Session', return_value=mock_session):
            with patch.object(AwsHelper, 'get_aws_profile', return_value='test-profile'):
                AwsHelper.create_boto3_client('stepfunctions')
                _, kwargs = mock_session.client.call_args
                config = kwargs.get('config')
                assert config is not None
                assert (
                    config.user_agent_extra
                    == f'awslabs/mcp/aws-stepfunctions-tool-mcp-server/{__version__}'
                )



"""Tests for the format_state_machine_response function."""

import json
import pytest
from unittest.mock import MagicMock


with pytest.MonkeyPatch().context() as CTX:
    CTX.setattr('boto3.Session', MagicMock)
    from awslabs.stepfunctions_tool_mcp_server.server import format_state_machine_response


class TestFormatResponse:
    """Tests for the format_state_machine_response function."""

    def test_format_response_json_success(self):
        """Test formatting a successful JSON response."""
        # Set up test data
        payload = json.dumps({'result': 'success'}).encode()

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert 'State machine test-state-machine returned:' in result
        assert '"result": "success"' in result

    def test_format_response_non_json(self):
        """Test formatting a non-JSON response."""
        # Set up test data
        payload = b'Non-JSON response'

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert result == "State machine test-state-machine returned payload: b'Non-JSON response'"

    def test_format_response_invalid_json(self):
        """Test formatting an invalid JSON response."""
        # Set up test data
        payload = b'{invalid json}'

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert 'State machine test-state-machine returned payload:' in result
        assert str(payload) in result

    def test_format_response_unicode_error(self):
        """Test formatting a response that causes UnicodeDecodeError."""
        # Create a binary payload that will cause UnicodeDecodeError
        payload = b'{"key": "\x80\x81\x82\x83"}'

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert 'State machine test-state-machine returned payload:' in result
        assert str(payload) in result

    def test_format_response_complex_json(self):
        """Test formatting a complex JSON response."""
        # Set up test data with nested structure
        complex_data = {
            'data': {
                'nested': {
                    'array': [1, 2, 3],
                    'object': {'key': 'value'},
                    'null': None,
                    'boolean': True,
                }
            },
            'metadata': {'timestamp': '2023-01-01T00:00:00Z', 'requestId': '12345'},
        }
        payload = json.dumps(complex_data).encode()

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert 'State machine test-state-machine returned:' in result
        assert '"data": {' in result
        assert '"nested": {' in result
        assert '"array": [' in result
        assert '"metadata": {' in result

    def test_format_response_empty_json(self):
        """Test formatting an empty JSON response."""
        # Set up test data
        payload = b'{}'

        # Call the function
        result = format_state_machine_response('test-state-machine', payload)

        # Verify results
        assert 'State machine test-state-machine returned: {}' in result
